import 'package:flutter/material.dart';
import 'dart:async';
import 'package:flutter/services.dart';
import 'package:mzanalytics_mybmw/mzanalytics_mybmw.dart';
import 'dart:io';
import "package:mzanalytics_mybmw_example/about_page.dart";

void main() {
  runApp(MyApp());
}

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  String _cid = 'Unknown';
  String _oaid = 'Unknown';
  String _myevent = '自定义事件';

  @override
  void initState() {
    super.initState();
  }

  // Platform messages are asynchronous, so we initialize in an async method.
  Future<void> android_initEvent() async {
    try {
      MzanalyticsMybmw.android_initEvent();
    } on PlatformException {}
    if (!mounted) return;
  }

  Future<void> android_sendBaseEvent() async {
    try {
      MzanalyticsMybmw.android_sendBaseEvent({
        "dt": '首⻚⻚面',
        "ec": '点击热⻔banner',
        "ea": 'Click',
        "el": '点击',
        "ev": '10',
      });
    } on PlatformException {}
    if (!mounted) return;
  }

  Future<void> android_pageEvent() async {
    try {
      MzanalyticsMybmw.android_pageEvent({
        "dt": '底部导航栏',
      });
    } on PlatformException {}
    if (!mounted) return;
  }

  Future<void> android_seniorEvent() async {
    try {
      MzanalyticsMybmw.android_seniorEvent({
        "cal1": '提交订单',
        "cal2": '支付订单',
        "cav1": '提交订单数',
        "cav2": '支付订单数',
        "caid": '1',
      });
    } on PlatformException {}
    if (!mounted) return;
  }

  Future<void> android_heartEvent() async {
    try {
      MzanalyticsMybmw.android_heartEvent();
    } on PlatformException {}
    if (!mounted) return;
  }

  // Platform messages are asynchronous, so we initialize in an async method.
  Future<void> ios_event() async {
    String cid;

    const timeout = const Duration(seconds: 2);
    const ms = const Duration(milliseconds: 1);

    // startTimeout([int milliseconds]) {
    //   var duration = milliseconds == null ? timeout : ms * milliseconds;
    //   return new Timer(duration, handleTimeout);
    // }

    // new Timer(timeout, handleTimeout);

    // If the widget was removed from the tree while the asynchronous platform
    // message was in flight, we want to discard the reply rather than calling
    // setState to update our non-existent appearance.
  }

  void getcid() async {
    // callback function

    String cid;
    if (Platform.isIOS) {
      cid = await MzanalyticsMybmw.ios_getCid;
    } else if (Platform.isAndroid) {
      cid = await MzanalyticsMybmw.android_getCid();
    }
    setState(() {
      _cid = cid;
    });
  }

  void getoaid() async {
    // callback function

    String oaid;
    if (Platform.isIOS) {
      oaid = "无";
    } else if (Platform.isAndroid) {
      oaid = await MzanalyticsMybmw.android_getOaid();
    }
    setState(() {
      _oaid = oaid;
    });
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      // navigatorObservers: [MZNavigationHistoryObserver()],
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Container(
          padding: EdgeInsets.all(10.0),
          child: Column(
            children: <Widget>[
              RaisedButton(
                onPressed: () {
                  if (Platform.isIOS) {
                    MzanalyticsMybmw.ios_appid("2815");
                  } else if (Platform.isAndroid) {
                    android_initEvent();
                  }
                },
                child: Text('初始化'),
              ),
              RaisedButton(
                onPressed: () {
                  if (Platform.isIOS) {
                    MzanalyticsMybmw.ios_trackPageView({'pageTitle': "页面"});
                  } else if (Platform.isAndroid) {
                    android_pageEvent();
                  }
                },
                child: Text('页面事件'),
              ),
              RaisedButton(
                onPressed: () {
                  if (Platform.isIOS) {
                    MzanalyticsMybmw.ios_trackEvent({
                      'eventClassify': '点击热门banner',
                      'eventAction': 'Click',
                      'eventTag': '点击'
                    });
                  } else if (Platform.isAndroid) {
                    android_sendBaseEvent();
                  }
                },
                child: Text('自定义事件监测'),
              ),
              RaisedButton(
                onPressed: () {
                  if (Platform.isIOS) {
                    MzanalyticsMybmw.ios_trackSiteCustomEvent({
                      'CustomEvent': {
                        "caid": "1",
                        "cal1": "2020/01/10",
                        "cal2": "15728749249",
                        "cal3": "北京",
                        "cav1": "2"
                      },
                      'CustomDimMetrics': {
                        "cd1": "点击信用卡",
                        "cd2": "查看商品详情",
                        "cm1": "点击信用卡总用户数",
                        "cm2": "查看商品详情总用户数"
                      }
                    });
                  } else if (Platform.isAndroid) {
                    android_seniorEvent();
                  }
                },
                child: Text('高级自定义事件'),
              ),
              RaisedButton(
                onPressed: () {
                  if (Platform.isIOS) {
                    MzanalyticsMybmw.ios_trackPulse;
                  } else if (Platform.isAndroid) {
                    android_heartEvent();
                  }
                },
                child: Text('心跳事件'),
              ),
              RaisedButton(
                onPressed: () {
                  getcid();
                },
                child: Text('cid: $_cid\n'),
              ),
              RaisedButton(
                onPressed: () {
                  getoaid();
                },
                child: Text('oaid: $_oaid\n'),
              ),
              //自定义事件IO操作
              RaisedButton(
                onPressed: () {
                  MzanalyticsMybmw.getCdAndCm();
                  Navigator.push(
                    context,
                    new MaterialPageRoute(
                        builder: (context) => new AboutPage()),
                  );
                },
                child: Text("自定义事件-读:$_myevent\n"),
              ),
              RaisedButton(
                onPressed: () {
                  MzanalyticsMybmw.setCd("cd2", "cd2qqqqqq");
                },
                child: Text("设置cd"),
              ),
              RaisedButton(
                onPressed: () {
                  MzanalyticsMybmw.setCm("cm2", "cm22222qqqq");
                },
                child: Text("设置cm"),
              ),
              RaisedButton(
                onPressed: () {
                  MzanalyticsMybmw.deleteCd("cd2");
                },
                child: Text("删除cd"),
              ),
              RaisedButton(
                onPressed: () {
                  MzanalyticsMybmw.deleteCd("cm2");
                },
                child: Text("删除cm"),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
